#include "i2c.h"
#include "nrf_assert.h"

ret_code_t i2c_init(const i2c_instance_t *i2c, const nrf_drv_twi_config_t *config)
{
    ASSERT(i2c);
    ASSERT(config);

    ret_code_t errCode;
    errCode = nrf_drv_twi_init(i2c, config, NULL, NULL);
    if (errCode != NRF_SUCCESS) {
        return errCode;
    }

    nrf_drv_twi_enable(i2c);

    return NRF_SUCCESS;
    
}

ret_code_t i2c_ping(const i2c_instance_t *i2c, uint8_t address)
{
    ASSERT(i2c);
    ASSERT(address > 0);

    ret_code_t errCode;
    uint8_t sampleData;
    errCode = nrf_drv_twi_rx(i2c, address, &sampleData, sizeof(sampleData));
    
    return errCode;
}

ret_code_t i2c_writeBytes(const i2c_instance_t *i2c, uint8_t address,
    const uint8_t const *data, uint8_t numBytes, bool writeStopBitFlag)
{
    ASSERT(i2c);
    ASSERT(data);
    
    ret_code_t errCode;
        
    errCode = nrf_drv_twi_tx(i2c, address, data, numBytes, !writeStopBitFlag);
    if (errCode != NRF_SUCCESS) {
        return errCode;
    }

    return NRF_SUCCESS;
}

ret_code_t i2c_readBytes(const i2c_instance_t *i2c, uint8_t address,
    uint8_t *buffer, uint8_t numBytes)
{
    ASSERT(i2c);
    ASSERT(buffer);

    ret_code_t errCode;

    errCode = nrf_drv_twi_rx(i2c, address, buffer, numBytes);
    if (errCode != NRF_SUCCESS) {
        return errCode;
    }

    return NRF_SUCCESS;
}
